registerWith static method
void
registerWith()
Registers this class as the default instance of SystemStatusPlatform
Implementation
static void registerWith() {
SystemStatusPlatform.instance = SystemStatusMacOS();
}
Registers this class as the default instance of SystemStatusPlatform
static void registerWith() {
SystemStatusPlatform.instance = SystemStatusMacOS();
}